@@ -4,9 +4,24 @@ Modified by A. Mathelier in March 2020
 """
 
 from Bio import SeqIO
+from os.path import splitext
+import gzip
 import re
 
 
+def open_for_parsing(filename):
+    """
+    Open the file with the given filename for parsing. Where the file appears
+    to be a gzip-compressed file it is opened in the appropriate way to provide
+    access to the decompressed text.
+    """
+    ext = splitext(filename)[-1]
+    if ext == ".gz":
+        return gzip.open(filename, "rt")  # text flag "t" needed in Python 3
+    else:
+        return open(filename)
+
+
 def GC(seq):
     """
     Calculate G+C content, return the percentage (float between 0 and 100).
@@ -42,7 +57,7 @@ def get_seqs(f):
     fg_gc_list = []
     fg_lengths = []
     dinuc = [0] * 16
-    with open(f) as stream:
+    with open_for_parsing(f) as stream:
         for record in SeqIO.parse(stream, "fasta"):
             record.seq = record.seq.upper()
             seqs.append(record)
@@ -226,7 +241,7 @@ def make_gc_plot(fg_gc, bg_gc, plot_filename):
                         label='generated')
     plt.legend()
     plot.set(xlabel="%GC", ylabel=ylab)
-    plt.savefig("{0}_gc_plot.png".format(plot_filename))
+    plt.savefig("{0}/{0}_gc_plot.png".format(plot_filename))
 
 
 def make_len_plot(fg_len, bg_len, plot_filename):
@@ -256,7 +271,7 @@ def make_len_plot(fg_len, bg_len, plot_filename):
                         label='generated')
     plt.legend()
     plot.set(xlabel="length", ylabel=ylab)
-    plot.get_figure().savefig("{0}_length_plot.png".format(plot_filename))
+    plot.get_figure().savefig("{0}/{0}_length_plot.png".format(plot_filename))
 
 
 def make_dinuc_plot(fg_dinuc, bg_dinuc, plot_filename):
@@ -297,4 +312,4 @@ def make_dinuc_plot(fg_dinuc, bg_dinuc, plot_filename):
                  use_gridspec=False, pad=0.2)
     ax2.yaxis.tick_right()
     ax2.tick_params(labelrotation=0)
-    plt.savefig("{0}_dinuc_plot.png".format(plot_filename))
+    plt.savefig("{0}/{0}_dinuc_plot.png".format(plot_filename))
